@@ -17,6 +17,19 @@ class Facet(Lattice):
         if not np.isin(should_be_in_index, obj.index).all():
             raise AttributeError(f"Must have {should_be_in_index} indexes in series.")
 
+    @staticmethod
+    def construct(ID, B, R=None, W=None, **kwargs) -> pd.Series:
+        d = {
+            **{
+                SupportFieldType.B.value: B,
+                SupportFieldType.ID.value: ID,
+                SupportFieldType.R.value: R,
+                SupportFieldType.W.value: W,
+            },
+            **kwargs,
+        }
+        return pd.Series(d)
+
     @property
     def variables(self):
-        return self._obj.index[self._obj.index != SupportFieldType.B.value]
\ No newline at end of file
+        return self._obj.index[self._obj.index != SupportFieldType.B.value]
